===================================
Karbor: Application Data Protection
===================================

Introduction
============
Karbor is an OpenStack project that provides a pluggable framework for
protecting and restoring Data and Metadata that comprises an OpenStack-deployed
application - Application Data Protection as a Service.

Mission Statement
~~~~~~~~~~~~~~~~~
To protect the Data and Metadata that comprises an OpenStack-deployed
Application against loss/damage (e.g. backup, replication) by providing a
standard framework of APIs and services that allows vendors to provide plugins
through a unified interface

Using Karbor
============
.. toctree::
   :maxdepth: 1

   readme
   installation
   usage
   contributing
   releasenotes

Available Plugins
=================
.. toctree::
   :maxdepth: 2

   bank_plugins
   protectable_plugins
   protection_plugins

Karbor Specs
============
.. toctree::
   :maxdepth: 1

   specs/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

